:mod: Autogenerated API Documentation
-------------------------------------

Autogenerated API
=================

.. automodule:: seaflux.flux_calculations
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seaflux.fco2_pco2_conversion
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seaflux.gas_transfer_velocity
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seaflux.solubility
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seaflux.vapour_pressure
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seaflux.auxiliary_equations
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seaflux.area
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: seaflux.data
   :members:
   :undoc-members:
   :show-inheritance:
